Search Settings
Result Limit
You have gone below the minimum ({$ ctrl.settings.general.limit_min $}) allowed. You have exceeded the maximum ({$ ctrl.settings.general.limit_max $}) allowed.
Enable highlighting
Search all projects
Poll for Updates
Update Interval (seconds) You have gone below the minimum ({$ ctrl.settings.polling.interval_min $}) allowed. You have exceeded the maximum ({$ ctrl.settings.polling.interval_max $}) allowed.

These settings impact the processing of results returned from the search service. Changing these settings may impact search performance and results.

It is typically better to filter results further than to increase the number of returned results and page through them.

Polling enables you to create a view of the data the updates periodically.